@@ -6,7 +6,7 @@ using FastClosures: @closure
 using Preferences: @load_preference, @set_preferences!
 
 using ADTypes: ADTypes, AbstractADType, AutoSparse, AutoForwardDiff, NoSparsityDetector,
-               KnownJacobianSparsityDetector
+    KnownJacobianSparsityDetector
 using Adapt: WrappedArray
 using ArrayInterface: ArrayInterface
 using DifferentiationInterface: DifferentiationInterface, Constant
@@ -17,20 +17,20 @@ using EnzymeCore: EnzymeCore
 using MaybeInplace: @bb
 using RecursiveArrayTools: RecursiveArrayTools, AbstractVectorOfArray, ArrayPartition
 using SciMLBase: SciMLBase, ReturnCode, AbstractODEIntegrator, AbstractNonlinearProblem,
-                 AbstractNonlinearAlgorithm, _concrete_solve_adjoint, _concrete_solve_forward,
-                 NonlinearProblem, NonlinearLeastSquaresProblem,
-                 NonlinearFunction, NLStats, LinearProblem,
-                 LinearAliasSpecifier, ImmutableNonlinearProblem, NonlinearAliasSpecifier,
-                 promote_u0, get_concrete_u0, get_concrete_p,
-                 has_kwargs, extract_alg, promote_u0, checkkwargs, SteadyStateProblem,
-                 NoDefaultAlgorithmError, NonSolverError, KeywordArgError, AbstractDEAlgorithm
+    AbstractNonlinearAlgorithm, _concrete_solve_adjoint, _concrete_solve_forward,
+    NonlinearProblem, NonlinearLeastSquaresProblem,
+    NonlinearFunction, NLStats, LinearProblem,
+    LinearAliasSpecifier, ImmutableNonlinearProblem, NonlinearAliasSpecifier,
+    promote_u0, get_concrete_u0, get_concrete_p,
+    has_kwargs, extract_alg, promote_u0, checkkwargs, SteadyStateProblem,
+    NoDefaultAlgorithmError, NonSolverError, KeywordArgError, AbstractDEAlgorithm
 import SciMLBase: solve, init, __init, __solve, wrap_sol, get_root_indp, isinplace, remake
 
 using SciMLJacobianOperators: JacobianOperator, StatefulJacobianOperator
 using SciMLOperators: AbstractSciMLOperator, IdentityOperator
 using SciMLLogging: SciMLLogging, @SciMLMessage, @verbosity_specifier,
-                    AbstractVerbositySpecifier, AbstractVerbosityPreset,
-                    None, Minimal, Standard, Detailed, All, Silent, InfoLevel, WarnLevel
+    AbstractVerbositySpecifier, AbstractVerbosityPreset, AbstractMessageLevel,
+    None, Minimal, Standard, Detailed, All, Silent, InfoLevel, WarnLevel
 
 using SymbolicIndexingInterface: SymbolicIndexingInterface
 import SciMLStructures
@@ -75,26 +75,32 @@ include("forward_diff.jl")
 # Unexported Public API
 @compat(public, (L2_NORM, Linf_NORM, NAN_CHECK, UNITLESS_ABS2, get_tolerance))
 @compat(public, (nonlinearsolve_forwarddiff_solve, nonlinearsolve_dual_solution))
-@compat(public,
-    (select_forward_mode_autodiff, select_reverse_mode_autodiff, select_jacobian_autodiff))
+@compat(
+    public,
+    (select_forward_mode_autodiff, select_reverse_mode_autodiff, select_jacobian_autodiff)
+)
 
 # public for NonlinearSolve.jl and subpackages to use
 @compat(public, (InternalAPI, supports_line_search, supports_trust_region, set_du!))
 @compat(public, (construct_linear_solver, needs_square_A, needs_concrete_A))
 @compat(public, (construct_jacobian_cache, reused_jacobian))
-@compat(public,
-    (assert_extension_supported_termination_condition,
-    construct_extension_function_wrapper, construct_extension_jac))
+@compat(
+    public,
+    (
+        assert_extension_supported_termination_condition,
+        construct_extension_function_wrapper, construct_extension_jac,
+    )
+)
 
 export TraceMinimal, TraceWithJacobianConditionNumber, TraceAll
 
 export RelTerminationMode, AbsTerminationMode,
-       NormTerminationMode, RelNormTerminationMode, AbsNormTerminationMode,
-       RelNormSafeTerminationMode, AbsNormSafeTerminationMode,
-       RelNormSafeBestTerminationMode, AbsNormSafeBestTerminationMode
+    NormTerminationMode, RelNormTerminationMode, AbsNormTerminationMode,
+    RelNormSafeTerminationMode, AbsNormSafeTerminationMode,
+    RelNormSafeBestTerminationMode, AbsNormSafeBestTerminationMode
 
 export DescentResult, SteepestDescent, NewtonDescent, DampedNewtonDescent, Dogleg,
-       GeodesicAcceleration
+    GeodesicAcceleration
 
 export NonlinearSolvePolyAlgorithm
 
